package VMOMI::ClusterDasConfigInfoHBDatastoreCandidate;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
